# SPDX-FileCopyrightText: 2024 Tom Hubrecht <tom.hubrecht@dgnum.eu>
#
# SPDX-License-Identifier: EUPL-1.2

{ config, ... }:

{
  services.nginx.virtualHosts.${config.services.pretalx.nginx.domain} = {
    enableACME = true;
    forceSSL = true;
  };

  services.pretalx = {
    enable = true;

    plugins = with config.services.pretalx.package.plugins; [
      pages
      venueless
    ];

    nginx = {
      enable = true;
      domain = "pretalx.dgnum.eu";
    };

    environmentFile = config.age.secrets."pretalx-environment_file".path;

    settings = {
      files.upload_limit = 50;

      mail = {
        from = "pretalx@infra.dgnum.eu";
        host = "kurisu.lahfa.xyz";
        port = 465;
        ssl = true;
        user = "web-services@infra.dgnum.eu";
      };

      logging.email = "admins+pretalx@dgnum.eu";

      locale = {
        language_code = "fr";
        time_zone = "Europe/Paris";
      };
    };
  };

  dgn-backups = {
    postgresDatabases = [ "pretalx" ];
    jobs.pretix.settings.paths = [ "/var/lib/pretalx" ];
  };
}
